@@ -1,7 +1,7 @@
 #! /bin/false
 
 # vim: tabstop=4
-# $Id: TextDomain.pm,v 1.20 2003/11/28 16:47:32 guido Exp $
+# $Id: TextDomain.pm,v 1.22 2003/11/30 18:47:20 guido Exp $
 
 # High-level interface to Perl i18n.
 # Copyright (C) 2002-2003 Guido Flohr <guido@imperia.net>,
@@ -68,7 +68,7 @@ use Locale::Messages qw (bindtextdomain dgettext dngettext);
 
 use vars qw ($VERSION);
 
-$VERSION = '1.07';
+$VERSION = '1.08';
 
 require Exporter;
 
@@ -388,10 +388,6 @@ F</usr/lib/perl/5.8.0/site_perl> is in your C<@INC>, you can
 install your translation files in F</usr/lib/perl/5.8.0/site_perl/LocaleData>, 
 and they will be found at run-time.
 
-The document L<http://let.imperia.org/howto/en/perl-i18n/> describes
-in detail, how you can install translations so that libintl-perl
-will find them without any additional hassle.
-
 =head1 USAGE
 
 It is crucial to remember that you use Locale::TextDoamin(3) as 
@@ -813,9 +809,6 @@ over and over again.  Although libintl-perl will of course cache
 the translation read from the file system, you can still avoid the
 overhead for the function calls.
 
-Up-to-date and in-depth information on the entire topic can be found at
-L<http://let.imperia.org/howto/en/perl-i18n/>.
-
 =head1 AUTHOR
 
 Copyright (C) 2002-2003, Guido Flohr E<lt>guido@imperia.netE<gt>, all
